#
# spec file for package python-formencode
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.



%define modname FormEncode

Name:           python-formencode
Summary:        HTML Form Validation, Generation, and Conversion Package
Version:        1.2.2
Release:        1.1
Url:            http://formencode.org/
License:        PSF
Group:          Development/Libraries/Python
Source:         %{modname}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}
BuildRequires:  python-devel python-setuptools
#Requires:       python-setuptools

%description
FormEncode validates and converts nested structures. It allows for a
declarative form of defining the validation, and decoupled processes for
filling and generating forms.

Authors:
--------
    Ian Bicking <ianb@colorstudy.com>

%prep
%setup -q -n %{modname}-%{version}
chmod -x docs/build

%build
export CFLAGS="$RPM_OPT_FLAGS"
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=$RPM_BUILD_ROOT --record-rpm=INSTALLED_FILES

%clean
rm -rf %{buildroot}

%files -f INSTALLED_FILES
%defattr(-,root,root)
%doc docs examples

%changelog
* Sun Jun  7 2009 lars@linux-schulserver.de
- disable runtime dependency to python-setuptools
* Mon Apr 27 2009 lars@linux-schulserver.de
- update to 1.2.2
- remove FormEncode-1.2-svn-fixes.patch
- added rpmlintrc
* Sun Dec 14 2008 jfunk@funktronics.ca
- Apply some fixes from SVN
* Wed Dec  3 2008 jfunk@funktronics.ca
- Update to 1.2
  * Added :class:`formencode.validators.IPAddress`, validating IP
  addresses, from Leandro Lucarella.
  * Added :meth:`formencode.api.Invalid.__unicode__`
  * In :mod:`formencode.htmlfill` use a default encoding of utf8 when
  handling mixed ``str``/``unicode`` content.  Also do not modify
  ``<input type="image">`` tags (previously ``src`` would be
  overwritten, for no good reason).
  * In :class:`formencode.validators.Email` allow single-character
  domain names (like x.com).
  * Make :class:`formencode.validators.FieldsMatch` give a normal
  ``Invalid`` exception if you pass it a non-dictionary.  Also treat
  all missing keys as the empty string (previously the first key was
  required and would raise KeyError).
  * :class:`formencode.validators.Number` works with ``inf`` float
  values (before it would raise a OverflowError).
  * The ``tw`` locale has been renamed to the more standard ``zh_TW``.
  * Added Japanese and Turkish translations.
  * Fixed some outdated translations and errors in Spanish and Greek
  translations. Translations now managed with `Babel
  <http://babel.edgewall.org/>`_.
- 1.1
  * Fixed the ``is_empty()`` method in
  :class:`formencode.validators.FieldStorageUploadConverter`;
  previously it returned the opposite of the intended result.
  * Added a parameter to ``htmlfill.render()``: ``prefix_error``.  If
  this parameter is true (the default) then errors automatically go
  before the input field; if false then they go after the input field.
  * Remove deprecated modules: ``fields``, ``formgen``, ``htmlform``,
  ``sqlformgen``, and ``sqlschema``.
  * Added ``formencode.htmlrename``, which renames HTML inputs.
  * In ``formencode.htmlfill``, non-string values are compared usefully
  (e.g., a select box with integer values).
  * The validators ``Int`` and ``Number`` both take min/max arguments
  (from Shannon Behrens).
  * Validators based on ``formencode.validators.FormValidator`` will not
  treat ``{}`` as an empty (unvalidated) value.
  * Some adjustments to the URL validator.
  * :class:`formencode.compound.All` does not handle empty values,
  instead relying on sub-validators to check for emptiness.
  * Fixed the ``if_missing`` attribute in
  :class:`formencode.foreach.ForEach`; previously it would be the same
  list instance, so if you modified it then it would effect future
  ``if_missing`` values (reported by Felix Schwarz).
  * Added formatter to :mod:`formencode.htmlfill`, so you can use
  ``<form:error name="field_name" formatter="ignore" />`` -- this will
  cause the error to be swallowed, not shown to the user.
  * Added :class:`formencode.validators.XRI` for validation i-names,
  i-numbers, URLs, etc (as used in OpenID).
  * Look in ``/usr/share/locale`` for locale files, in addition to the
  normal locations.
  * Quiet Python 2.6 deprecation warnings.
  * Fix :class:`formencode.validators.URL`, which was accepting illegal
  characters (like newlines) and did not accept http://domain:PORT/
- 1.0.1
  * ``chained_validators`` were removed from Schema somehow; now
  replaced and working.
  * Put in missing ``htmlfill.render(error_class=...)`` parameter (was
  documented and implemented, but ``render()`` did not pass it
  through).
* Tue Nov 11 2008 @gmail.com
- try building with --record-rpm instead of --record - 1.0-1
* Wed Mar 19 2008 jfunk@funktronics.ca
- Update to 1.0
* Thu Dec 27 2007 jfunk@funktronics.ca
- Fix bad python interpreter path
* Tue Dec 18 2007 jfunk@funktronics.ca
- Update to 0.9:
  - Backward incompatible changes
  * The notion of "empty" has changed to include empty lists,
  dictionaries, and tuples.  If you get one of these values passed
  into (or generated by) a validator with ``not_empty=True`` you can
  get exceptions where you didn't previously.
  - Enhancements
  * Added support for Paste's MultiDict dictionary as input to
  Schema.to_python, by converting it to a normal dict via MultiDict.mixed.
  Previously MultiDicts wouldn't work with CompoundValidators (like
  ForEach)
  * Added encoding parameter to htmlfill, which will handle cases when mixed
  str and unicode objects are used (turning all str objects into unicode)
  * Include ``formencode.validators.InternationalPhoneNumber`` from
  W-Mark Kubacki.
  * ``validators.Int`` takes ``min`` and ``max`` options (from Felix
  Schwarz).
  * You can control the missing message (which by default is just
  "Missing Value") using the message ``"missing"`` in a validator
  (also from James Gardner).
  * Added ``validators.CADR`` (for IP addresses with an optional range)
  and ``validators.MACAddress`` (from Christoph Haas).
  - Bug Fixes
  * Be friendlier when loaded from a zip file (as with py2exe);
  previously only egg zip files would work.
  * Fixed bug in htmlfill when a document ends with no trailing text
  after the last tag.
  * Fix problem with HTMLParser's default unescaping routing, which only
  understood a very limited number of entities in attribute values.
  * Fix problem with looking up A records for email addresses.
  * ``validators.String`` now always returns strings.  It also converts
  lists to comma-separated strings (no ``[...]``), and can encode
  unicode if an ``encoding`` parameter is given.  Empty values are
  handled better.
  * ``validators.UnicodeString`` properly handles non-Unicode inputs.
  * Make ``validators.DateConverter`` serialize dates properly
  (from James Gardner).
  * Minor fix to setup.py to make FormEncode more friendly with
  zc.buildout.
* Mon Apr 23 2007 jfunk@funktronics.ca
- Update to 0.7.1:
  From 0.7.1:
  * Set ``if_missing=()`` on ``validators.Set``, as a missing value
  usually means empty for this value.
  * Fix for ``Email`` validator that searches A records in addition to
  MX records (from Jacob Smullyan).
  * Fixes for the ``es`` locale.
  From 0.7:
  * **Backward compatibility issue**: Due to the addition of i18n
  (internationalization) to FormEncode, Invalid exceptions now have
  unicode messages.  You may encounter unicode-related errors if you
  are mixing these messages with non-ASCII ``str`` strings.
  * gettext-enabled branch merged in
  * Fixes `#1457145: Fails on URLs with port numbers
  <http://sourceforge.net/tracker/index.php?func=detail&aid=1457145&group_id=91231&atid=596416>`_
  * Fixes `#1559918 Schema fails to accept unicode errors
  <http://sourceforge.net/tracker/index.php?func=detail&aid=1559918&group_id=91231&atid=596416>`_
  * ``from formencode.validators import *`` will import the ``Invalid``
  exception now.
  * ``Invalid().unpack_errors(encode_variables=True)`` now filters out
  None values (which ``ForEach`` can produce even for keys with no
  errors).
* Mon Jan  8 2007 - poeml@suse.de
- update to 0.6
* Mon Jun 26 2006 jfunk@funktronics.ca
- Remove noarch
* Fri Jun 23 2006 jfunk@funktronics.ca
- No longer need pth kludge
* Thu Jun 22 2006 jfunk@funktronics.ca
- Update
* Thu Oct 13 2005 jfunk@funktronics.ca
- Initial release
